#########################################################################################################
# Analysis of reliability in filtering the literature to be included in the ehealth4mdd database. 
# 2018 TUDelft
# Author: Franziska Burger
# Output: title sample, abstract sample, full-paper sample
# Required files: 
# - filter_results_coder1.txt
#########################################################################################################

################################# LIBRARIES ###################
require(foreign)
require(car)
require(dplyr)
require(plyr)
require(tidyr)
require(reshape)
require(irr)
require(psych)
#################################

################################# DATA ###################

########## filter_results_coder1.txt
# Contains the results of the title, abstract, and full paper filtering of records as done by coder 1

# data fields
#
# PaperKey: key of the record as assigned by endnote
# Title.R1: filtering information of first author on title (1-include, 0-exclude)
# Abstract.R1: filtering information of first author on abstract (1-include, 0-exclude, NA-was excluded on title already)
# Full.R1: filtering information of first author on full paper (1-include, 0-exclude, NA-was excluded on title or abstract already)

#read in file that contains filtering information of coder1
coder1.df <- read.table(file="filter_results_coder1.txt", header=TRUE, sep="\t", fill=TRUE)

###Sampling 
##selecting a random sample to have filtered by coder 2. Sample sizes are based on Handbook of Interrater Reliabilty (Gwet, 4th edition, Table 5.9)

#random sample for title filter, 40 for training, 100 for test
title_sample <- sort(sample(coder1.df$PaperKey, 140))
train_title <- sort(sample(title_sample,40))

#random sample for abstract filter, 10 for training, 54 for test
abstract_sample <- sort(sample(coder1.df[which(coder1.df$Title.R1==1),"PaperKey"], 64))
train_abstract <- sort(sample(abstract_sample,20))
abstract_include <- coder1.df[which(coder1.df$Title.R1==1),"PaperKey"]
abstract_sample_train2 <- sort(sample(setdiff(abstract_include,overlap_abte.df$PaperKey),20))

#random sample for full paper filter, 5 for training, 25 for test
full_sample <- sort(sample(coder1.df[which(coder1.df$Abstract.R1==1),"PaperKey"], 30))
train_full <- sort(sample(full_sample,5))
