#data folder
path <- "./preprocessing_and_raw_data/function_classification/"

#########################################################################################################
# Preprocessing of data for classification of instantiation descriptions as functions of all types.
# 2018 TUDelft
# Author: Franziska Burger
# Output file: function_classification_C1C3.txt
# Required files: 
# - classifying_C1.txt
# - classifying_C3.txt
# - keymapping.txt
#########################################################################################################

################################# libraries
#################################

########## classifying_C1.txt   
# File with ID of instantiation of a function (brief description taken from articles) and the function key that C1 assigned to this instantiation
#
# data fields
#
#1 ID: unique identifier for each function instantiation
#2 FunctionKey: the function key of the corresponding function 

########## classifying_C3.txt   
# File with ID of instantiation of a function (brief description taken from articles) and the function key that C3 assigned to this instantiation
#
# data fields
#
#1 ID: unique identifier for each function instantiation
#2 FunctionKey: the function key of the corresponding function as assigned by C3

########## key_mapping.txt   
# since there was an ordering according to function type in the IDs of C1, this ordering was randomized to obtain new IDs for C3. Key_mapping.txt contains
# the mapping of old keys (C1) to new keys (C3)
#
# data fields
#
#1 Order_Final: the new ordering of instantiations
#2 Order_Initial: the original ordering of instantiations

#reading in C1's and C3's classification list
df.classifyingC3 <- read.table(paste0(path,"classifying_C3.txt"), header=TRUE, sep="\t", fill=TRUE)
df.classifyingC1 <- read.table(paste0(path,"classifying_C1.txt"), header=TRUE, sep="\t", fill=TRUE)
df.classifyingC3$X <- NULL

#reading in the mapping of IDs as the order was randomized for C3
keymapping <- read.table(paste0(path,"key_mapping.txt"), header=TRUE, sep="\t", fill=TRUE)

#we merge C3 dataframe with keymapping on the IDs/Order_Final
df.classifyingC3 <- merge(df.classifyingC3,keymapping, by.x="ID", by.y="Order_Final")
df.classifyingC3$ID <- NULL

#now we can merge df.C3 with df.C1 on the IDs
df.classifying <- merge(df.classifyingC3, df.classifyingC1, by.x="Order_Initial", by.y="ID")
df.classifying <- rename(df.classifying,c("Function.C1"="C1","Function.C3"="C3"))

#and we write this to a file
write.table(df.classifying, "analysis/function_classification_C1C3.txt", sep="\t", row.names = FALSE)

