#set working directory to data folder
path <- paste0(getwd(),"/preprocessing_and_raw_data/validation/")

#########################################################################################################
# Analysis of concept validity of HDAS scales
# 2018 TUDelft
# Author: Franziska Burger
# Required files: 
# - [*INSERT-FUNCTION-TYPE-HERE*]Functions_raw_data.csv
# - [*INSERT-FUNCTION-TYPE-HERE*]FunctionswithScale_raw_data.csv
# - alltypes_rawdata.csv
# - alltypeswithscale_rawdata.csv
# - ehealth4mdd_cypsy.sql (running on a local mysql server)
#[*INSERT-FUNCTION-TYPE-HERE*]: one of [Intervention, Monitoring, Planning, Social, Execution]
#########################################################################################################

################################# LIBRARIES ###################
require(RMySQL)
require(Hmisc)
require(boot)
require(psych)
require(irr)
# RMySQL\n# Hmisc\n# boot\n# psych\n# irr
#################################

################################# DATA ###################
########## [*INSERT-FUNCTION-TYPE-HERE*]Functions_raw_data.csv   
# File with information on the cards and the assigned ehdts scores of coders when coders did not know what each number of the scale meant
#
# data fields
#
#1 participant: unique identified of the respective coder
#2 card index: ID of each card assigned by the software
#3 card label: VersionKey and FunctionKey, brief description of the function, and plattform on which the function is delivered in the specific version
#4 category label: ehdts score as assigned by the coder
#5 complete: whether the item was assigned a category label
#6 start time: when participant commenced coding
#7 finish time: when participant completed coding
#8 sorted position: order in which the participant assigned an ehdts score to the cards (1 means it was the first card that the participant assigned a score to)
#9-13 post-questionnaire: questions concerning the task for after the scoring
#
########## [*INSERT-FUNCTION-TYPE-HERE*]FunctionswithScale_raw_data.csv
# File with information on the cards and the assigned ehdts scores of coders when coders did know the definitions of scale levels. Fields are same as above. 
#
########## alltypes_rawdata.csv
# File with information cards from all function types mixed and the assigned ehdts scores of C2 without knowledge of different function types or scale levels. 
#
# data fields
#
#1 card.label: VersionKey and FunctionKey, brief description of the function, and plattform on which the function is delivered in the specific version
#2 category.label: ehdts score as assigned by the C2
#
########## alltypeswithscale_rawdata.csv
# File with information cards from all function types mixed and the assigned ehdts scores of C2 with knowledge of different function types and scale levels. 
#
########## ehealth4mdd_CYPSY23.sql   
# MySQL database to be run on a local mysql server. For this analysis, we only query from the VersionFunction table the following attributes:
#
# data fields
#
#1 VersionKey: identified the ehealth system.
#2 FunctionKey: identifies the function (together with VersionKey, this identifies a function instantiation) 
#3 eHDTS: ehdts score as assigned by the C1 \n ")
#################################

#function to extract VersionKey and FunctionKey from the card labels
vkfk <- function(df,newname){
  df$vkfk <- regmatches(df$card.label, gregexpr("[[:digit:]]+", df$card.label))
  df$VersionKey <- NaN
  df$FunctionKey <- NaN
  for(i in 1:nrow(df)){
    df[i,"VersionKey"] <- as.numeric(df$vkfk[[i]][1])
    df[i,"FunctionKey"] <- as.numeric(df$vkfk[[i]][2])
  }
  df[,newname] <- df$category.label
  df.out <- df[,c("VersionKey","FunctionKey",newname)]
  return(df.out)
}

#combine the codes that coder X (CX where X is element of {2,4,5,6,7,8}) assigned to items when uninformed and when informed with the codes assigned by coder 1 (C1)
mergeframes <- function(file1, file2,coderID){
  df1 <- vkfk(read.csv(file=paste0(path,file1), header=TRUE, fill=TRUE),"CXnoscale")
  df2 <- vkfk(read.csv(file=paste0(path,file2), header=TRUE, fill=TRUE),"CXscale")
  df.all <- merge(df1,df2, by=c("VersionKey","FunctionKey"), all=TRUE)
  df.all <- merge(df.all, df.C1, by=c("VersionKey","FunctionKey"),all.x=TRUE)
  names(df.all)[names(df.all) == 'eHDTS'] <- 'C1scale'
  df.all$coderID <- coderID
  return(df.all)
}

#get all assigned automation degrees from the database
#connect to the ehealth4mdd database
u <- 'root'
p <- 'insy'
n <- 'ehealth4mdd_CYPSY23'
h <- 'localhost'
ehealthdb = dbConnect(MySQL(), user=u, password=p, dbname=n, host=h)

#send query:
q <- 'select vf.VersionKey, vf.FunctionKey, vf.eHDTS from VersionFunction as vf'
query = dbSendQuery(ehealthdb, q)
print(q)

df.C1 <- fetch(query,n=-1)

#Coder X (CX) dataframe to compute naive with informed scores (intra) and to compare informed scores between CX and C1 and write this to a file
df.C4 <- mergeframes("raw_data/InterventionFunctions_raw_data.csv","raw_data/InterventionFunctionswithScale_raw_data.csv",4)
df.C5 <- mergeframes("raw_data/PlanningFunctions_raw_data.csv", "raw_data/PlanningFunctionswithScale_raw_data.csv", 5)
df.C6 <- mergeframes("raw_data/ExecutionFunctions_raw_data.csv", "raw_data/ExecutionFunctionswithScale_raw_data.csv", 6)
df.C7 <- mergeframes("raw_data/MonitoringFunctions_raw_data.csv","raw_data/MonitoringFunctionswithScale_raw_data.csv", 7)
df.C8 <- mergeframes("raw_data/SocialFunctions_raw_data.csv","raw_data/SocialFunctionswithScale_raw_data.csv", 8)
df.C2 <- mergeframes("raw_data/alltypes_rawdata.csv","raw_data/alltypeswithscale_rawdata.csv",2)
df.CX <- rbind(rbind(rbind(rbind(rbind(df.C4, df.C5), df.C6), df.C7), df.C8), df.C2)
write.table(df.CX, "analysis/validation_C1CX.txt",sep="\t", row.names = FALSE)

